@@ -1,8 +1,10 @@
-use Mix.Config
+import Config
 
 config :logger,
   backends: [:console],
-  compile_time_purge_level: :debug,
+  compile_time_purge_matching: [
+    [level_lower_than: :debug]
+  ],
   level: :debug
 
 config :kernel,
