@@ -23,14 +23,14 @@
 
 -define(PORT_OPTIONS, [stream, {line, 4096}, binary, exit_status, hide]).
 
--record(os_proc,
-    {command,
-     port,
-     writer,
-     reader,
-     timeout=5000,
-     idle
-    }).
+-record(os_proc, {
+    command,
+    port,
+    writer,
+    reader,
+    timeout = 5000,
+    idle
+}).
 
 start_link(Command) ->
     start_link(Command, []).
@@ -55,7 +55,7 @@ prompt(Pid, Data) ->
         {ok, Result} ->
             Result;
         Error ->
-            couch_log:error("OS Process Error ~p :: ~p",[Pid,Error]),
+            couch_log:error("OS Process Error ~p :: ~p", [Pid, Error]),
             throw(Error)
     end.
 
@@ -72,21 +72,21 @@ readline(#os_proc{} = OsProc) ->
     Res.
 readline(#os_proc{port = Port} = OsProc, Acc) ->
     receive
-    {Port, {data, {noeol, Data}}} when is_binary(Acc) ->
-        readline(OsProc, <<Acc/binary,Data/binary>>);
-    {Port, {data, {noeol, Data}}} when is_binary(Data) ->
-        readline(OsProc, Data);
-    {Port, {data, {noeol, Data}}} ->
-        readline(OsProc, [Data|Acc]);
-    {Port, {data, {eol, <<Data/binary>>}}} when is_binary(Acc) ->
-        [<<Acc/binary,Data/binary>>];
-    {Port, {data, {eol, Data}}} when is_binary(Data) ->
-        [Data];
-    {Port, {data, {eol, Data}}} ->
-        lists:reverse(Acc, Data);
-    {Port, Err} ->
-        catch port_close(Port),
-        throw({os_process_error, Err})
+        {Port, {data, {noeol, Data}}} when is_binary(Acc) ->
+            readline(OsProc, <<Acc/binary, Data/binary>>);
+        {Port, {data, {noeol, Data}}} when is_binary(Data) ->
+            readline(OsProc, Data);
+        {Port, {data, {noeol, Data}}} ->
+            readline(OsProc, [Data | Acc]);
+        {Port, {data, {eol, <<Data/binary>>}}} when is_binary(Acc) ->
+            [<<Acc/binary, Data/binary>>];
+        {Port, {data, {eol, Data}}} when is_binary(Data) ->
+            [Data];
+        {Port, {data, {eol, Data}}} ->
+            lists:reverse(Acc, Data);
+        {Port, Err} ->
+            catch port_close(Port),
+            throw({os_process_error, Err})
     after OsProc#os_proc.timeout ->
         catch port_close(Port),
         throw({os_process_error, "OS process timed out."})
@@ -95,8 +95,10 @@ readline(#os_proc{port = Port} = OsProc, Acc) ->
 % Standard JSON functions
 writejson(OsProc, Data) when is_record(OsProc, os_proc) ->
     JsonData = ?JSON_ENCODE(Data),
-    couch_log:debug("OS Process ~p Input  :: ~s",
-                    [OsProc#os_proc.port, JsonData]),
+    couch_log:debug(
+        "OS Process ~p Input  :: ~s",
+        [OsProc#os_proc.port, JsonData]
+    ),
     true = writeline(OsProc, JsonData).
 
 readjson(OsProc) when is_record(OsProc, os_proc) ->
@@ -109,24 +111,28 @@ readjson(OsProc) when is_record(OsProc, os_proc) ->
         % command, otherwise return the raw JSON line to the caller.
         pick_command(Line)
     catch
-    throw:abort ->
-        {json, Line};
-    throw:{cmd, _Cmd} ->
-        case ?JSON_DECODE(Line) of
-        [<<"log">>, Msg] when is_binary(Msg) ->
-            % we got a message to log. Log it and continue
-            couch_log:info("OS Process ~p Log :: ~s",
-                           [OsProc#os_proc.port, Msg]),
-            readjson(OsProc);
-        [<<"error">>, Id, Reason] ->
-            throw({error, {couch_util:to_existing_atom(Id),Reason}});
-        [<<"fatal">>, Id, Reason] ->
-            couch_log:info("OS Process ~p Fatal Error :: ~s ~p",
-                [OsProc#os_proc.port, Id, Reason]),
-            throw({couch_util:to_existing_atom(Id),Reason});
-        _Result ->
-            {json, Line}
-        end
+        throw:abort ->
+            {json, Line};
+        throw:{cmd, _Cmd} ->
+            case ?JSON_DECODE(Line) of
+                [<<"log">>, Msg] when is_binary(Msg) ->
+                    % we got a message to log. Log it and continue
+                    couch_log:info(
+                        "OS Process ~p Log :: ~s",
+                        [OsProc#os_proc.port, Msg]
+                    ),
+                    readjson(OsProc);
+                [<<"error">>, Id, Reason] ->
+                    throw({error, {couch_util:to_existing_atom(Id), Reason}});
+                [<<"fatal">>, Id, Reason] ->
+                    couch_log:info(
+                        "OS Process ~p Fatal Error :: ~s ~p",
+                        [OsProc#os_proc.port, Id, Reason]
+                    ),
+                    throw({couch_util:to_existing_atom(Id), Reason});
+                _Result ->
+                    {json, Line}
+            end
     end.
 
 pick_command(Line) ->
@@ -146,7 +152,6 @@ pick_command1(<<"fatal">> = Cmd) ->
 pick_command1(_) ->
     throw(abort).
 
-
 % gen_server API
 init([Command, Options, PortOptions]) ->
     couch_io_logger:start(os:getenv("COUCHDB_IO_LOG_DIR")),
@@ -155,34 +160,38 @@ init([Command, Options, PortOptions]) ->
     V = config:get("query_server_config", "os_process_idle_limit", "300"),
     IdleLimit = list_to_integer(V) * 1000,
     BaseProc = #os_proc{
-        command=Command,
-        port=open_port({spawn, Spawnkiller ++ " " ++ Command}, PortOptions),
-        writer=fun ?MODULE:writejson/2,
-        reader=fun ?MODULE:readjson/1,
-        idle=IdleLimit
+        command = Command,
+        port = open_port({spawn, Spawnkiller ++ " " ++ Command}, PortOptions),
+        writer = fun ?MODULE:writejson/2,
+        reader = fun ?MODULE:readjson/1,
+        idle = IdleLimit
     },
     KillCmd = iolist_to_binary(readline(BaseProc)),
     Pid = self(),
     couch_log:debug("OS Process Start :: ~p", [BaseProc#os_proc.port]),
     spawn(fun() ->
-            % this ensure the real os process is killed when this process dies.
-            erlang:monitor(process, Pid),
-            killer(?b2l(KillCmd))
-        end),
+        % this ensure the real os process is killed when this process dies.
+        erlang:monitor(process, Pid),
+        killer(?b2l(KillCmd))
+    end),
     OsProc =
-    lists:foldl(fun(Opt, Proc) ->
-        case Opt of
-        {writer, Writer} when is_function(Writer) ->
-            Proc#os_proc{writer=Writer};
-        {reader, Reader} when is_function(Reader) ->
-            Proc#os_proc{reader=Reader};
-        {timeout, TimeOut} when is_integer(TimeOut) ->
-            Proc#os_proc{timeout=TimeOut}
-        end
-    end, BaseProc, Options),
+        lists:foldl(
+            fun(Opt, Proc) ->
+                case Opt of
+                    {writer, Writer} when is_function(Writer) ->
+                        Proc#os_proc{writer = Writer};
+                    {reader, Reader} when is_function(Reader) ->
+                        Proc#os_proc{reader = Reader};
+                    {timeout, TimeOut} when is_integer(TimeOut) ->
+                        Proc#os_proc{timeout = TimeOut}
+                end
+            end,
+            BaseProc,
+            Options
+        ),
     {ok, OsProc, IdleLimit}.
 
-terminate(Reason, #os_proc{port=Port}) ->
+terminate(Reason, #os_proc{port = Port}) ->
     catch port_close(Port),
     case Reason of
         normal ->
@@ -192,10 +201,10 @@ terminate(Reason, #os_proc{port=Port}) ->
     end,
     ok.
 
-handle_call({set_timeout, TimeOut}, _From, #os_proc{idle=Idle}=OsProc) ->
-    {reply, ok, OsProc#os_proc{timeout=TimeOut}, Idle};
-handle_call({prompt, Data}, _From, #os_proc{idle=Idle}=OsProc) ->
-    #os_proc{writer=Writer, reader=Reader} = OsProc,
+handle_call({set_timeout, TimeOut}, _From, #os_proc{idle = Idle} = OsProc) ->
+    {reply, ok, OsProc#os_proc{timeout = TimeOut}, Idle};
+handle_call({prompt, Data}, _From, #os_proc{idle = Idle} = OsProc) ->
+    #os_proc{writer = Writer, reader = Reader} = OsProc,
     try
         Writer(OsProc, Data),
         {reply, {ok, Reader(OsProc)}, OsProc, Idle}
@@ -210,7 +219,7 @@ handle_call({prompt, Data}, _From, #os_proc{idle=Idle}=OsProc) ->
         garbage_collect()
     end.
 
-handle_cast({send, Data}, #os_proc{writer=Writer, idle=Idle}=OsProc) ->
+handle_cast({send, Data}, #os_proc{writer = Writer, idle = Idle} = OsProc) ->
     try
         Writer(OsProc, Data),
         {noreply, OsProc, Idle}
@@ -219,31 +228,31 @@ handle_cast({send, Data}, #os_proc{writer=Writer, idle=Idle}=OsProc) ->
             couch_log:error("Failed sending data: ~p -> ~p", [Data, OsError]),
             {stop, normal, OsProc}
     end;
-handle_cast(garbage_collect, #os_proc{idle=Idle}=OsProc) ->
+handle_cast(garbage_collect, #os_proc{idle = Idle} = OsProc) ->
     erlang:garbage_collect(),
     {noreply, OsProc, Idle};
 handle_cast(stop, OsProc) ->
     {stop, normal, OsProc};
-handle_cast(Msg, #os_proc{idle=Idle}=OsProc) ->
+handle_cast(Msg, #os_proc{idle = Idle} = OsProc) ->
     couch_log:debug("OS Proc: Unknown cast: ~p", [Msg]),
     {noreply, OsProc, Idle}.
 
-handle_info(timeout, #os_proc{idle=Idle}=OsProc) ->
-    couch_proc_manager:os_proc_idle(self()),
+handle_info(timeout, #os_proc{idle = Idle} = OsProc) ->
+    gen_server:cast(couch_proc_manager, {os_proc_idle, self()}),
     erlang:garbage_collect(),
     {noreply, OsProc, Idle};
-handle_info({Port, {exit_status, 0}}, #os_proc{port=Port}=OsProc) ->
+handle_info({Port, {exit_status, 0}}, #os_proc{port = Port} = OsProc) ->
     couch_log:info("OS Process terminated normally", []),
     {stop, normal, OsProc};
-handle_info({Port, {exit_status, Status}}, #os_proc{port=Port}=OsProc) ->
+handle_info({Port, {exit_status, Status}}, #os_proc{port = Port} = OsProc) ->
     couch_log:error("OS Process died with status: ~p", [Status]),
     {stop, {exit_status, Status}, OsProc};
-handle_info(Msg, #os_proc{idle=Idle}=OsProc) ->
+handle_info(Msg, #os_proc{idle = Idle} = OsProc) ->
     couch_log:debug("OS Proc: Unknown info: ~p", [Msg]),
     {noreply, OsProc, Idle}.
 
-code_change(_, {os_proc, Cmd, Port, W, R, Timeout} , _) ->
-    V = config:get("query_server_config","os_process_idle_limit","300"),
+code_change(_, {os_proc, Cmd, Port, W, R, Timeout}, _) ->
+    V = config:get("query_server_config", "os_process_idle_limit", "300"),
     State = #os_proc{
         command = Cmd,
         port = Port,
@@ -257,9 +266,9 @@ code_change(_OldVsn, State, _Extra) ->
     {ok, State}.
 
 killer(KillCmd) ->
-    receive _ ->
-        os:cmd(KillCmd)
+    receive
+        _ ->
+            os:cmd(KillCmd)
     after 1000 ->
         ?MODULE:killer(KillCmd)
     end.
-
