@@ -33,23 +33,28 @@ maybe_open_doc(Db, DocId) ->
         {not_found, _} -> nil
     end.
 
-handle_doc_show_req(#httpd{
-        path_parts=[_, _, _, _, ShowName, DocId]
-    }=Req, Db, DDoc) ->
-
+handle_doc_show_req(
+    #httpd{
+        path_parts = [_, _, _, _, ShowName, DocId]
+    } = Req,
+    Db,
+    DDoc
+) ->
     % open the doc
     Doc = maybe_open_doc(Db, DocId),
 
     % we don't handle revs here b/c they are an internal api
     % returns 404 if there is no doc with DocId
     handle_doc_show(Req, Db, DDoc, ShowName, Doc, DocId);
-
-handle_doc_show_req(#httpd{
-        path_parts=[_, _, _, _, ShowName, DocId|Rest]
-    }=Req, Db, DDoc) ->
-
-    DocParts = [DocId|Rest],
-    DocId1 = ?l2b(string:join([?b2l(P)|| P <- DocParts], "/")),
+handle_doc_show_req(
+    #httpd{
+        path_parts = [_, _, _, _, ShowName, DocId | Rest]
+    } = Req,
+    Db,
+    DDoc
+) ->
+    DocParts = [DocId | Rest],
+    DocId1 = ?l2b(string:join([?b2l(P) || P <- DocParts], "/")),
 
     % open the doc
     Doc = maybe_open_doc(Db, DocId1),
@@ -57,13 +62,15 @@ handle_doc_show_req(#httpd{
     % we don't handle revs here b/c they are an internal api
     % pass 404 docs to the show function
     handle_doc_show(Req, Db, DDoc, ShowName, Doc, DocId1);
-
-handle_doc_show_req(#httpd{
-        path_parts=[_, _, _, _, ShowName]
-    }=Req, Db, DDoc) ->
+handle_doc_show_req(
+    #httpd{
+        path_parts = [_, _, _, _, ShowName]
+    } = Req,
+    Db,
+    DDoc
+) ->
     % with no docid the doc is nil
     handle_doc_show(Req, Db, DDoc, ShowName, nil);
-
 handle_doc_show_req(Req, _Db, _DDoc) ->
     chttpd:send_error(Req, 404, <<"show_error">>, <<"Invalid path.">>).
 
@@ -77,21 +84,29 @@ handle_doc_show(Req, Db, DDoc, ShowName, Doc, DocId) ->
         JsonReq = chttpd_external:json_req_obj(Req, Db, DocId),
         JsonDoc = couch_query_servers:json_doc(Doc),
         [<<"resp">>, ExternalResp] =
-            couch_query_servers:ddoc_prompt(Db, DDoc, [<<"shows">>, ShowName],
-                [JsonDoc, JsonReq]),
+            couch_query_servers:ddoc_prompt(
+                DDoc,
+                [<<"shows">>, ShowName],
+                [JsonDoc, JsonReq]
+            ),
         JsonResp = apply_etag(ExternalResp, CurrentEtag),
         chttpd_external:send_external_response(Req, JsonResp)
     end).
 
-
-show_etag(#httpd{user_ctx=UserCtx}=Req, Doc, DDoc, More) ->
+show_etag(#httpd{user_ctx = UserCtx} = Req, Doc, DDoc, More) ->
     Accept = chttpd:header_value(Req, "Accept"),
-    DocPart = case Doc of
-        nil -> nil;
-        Doc -> chttpd:doc_etag(Doc)
-    end,
-    chttpd:make_etag({chttpd:doc_etag(DDoc), DocPart, Accept,
-        {UserCtx#user_ctx.name, UserCtx#user_ctx.roles}, More}).
+    DocPart =
+        case Doc of
+            nil -> nil;
+            Doc -> chttpd:doc_etag(Doc)
+        end,
+    chttpd:make_etag({
+        chttpd:doc_etag(DDoc),
+        DocPart,
+        Accept,
+        {UserCtx#user_ctx.name, UserCtx#user_ctx.roles},
+        More
+    }).
 
 % updates a doc based on a request
 % handle_doc_update_req(#httpd{method = 'GET'}=Req, _Db, _DDoc) ->
@@ -101,20 +116,25 @@ show_etag(#httpd{user_ctx=UserCtx}=Req, Doc, DDoc, More) ->
 % This call is creating a new doc using an _update function to
 % modify the provided request body.
 % /db/_design/foo/_update/bar
-handle_doc_update_req(#httpd{
-        path_parts=[_, _, _, _, UpdateName]
-    }=Req, Db, DDoc) ->
+handle_doc_update_req(
+    #httpd{
+        path_parts = [_, _, _, _, UpdateName]
+    } = Req,
+    Db,
+    DDoc
+) ->
     send_doc_update_response(Req, Db, DDoc, UpdateName, nil, null);
-
 % /db/_design/foo/_update/bar/docid
-handle_doc_update_req(#httpd{
-        path_parts=[_, _, _, _, UpdateName | DocIdParts]
-    }=Req, Db, DDoc) ->
+handle_doc_update_req(
+    #httpd{
+        path_parts = [_, _, _, _, UpdateName | DocIdParts]
+    } = Req,
+    Db,
+    DDoc
+) ->
     DocId = ?l2b(string:join([?b2l(P) || P <- DocIdParts], "/")),
     Doc = maybe_open_doc(Db, DocId),
     send_doc_update_response(Req, Db, DDoc, UpdateName, Doc, DocId);
-
-
 handle_doc_update_req(Req, _Db, _DDoc) ->
     chttpd:send_error(Req, 404, <<"update_error">>, <<"Invalid path.">>).
 
@@ -122,33 +142,37 @@ send_doc_update_response(Req, Db, DDoc, UpdateName, Doc, DocId) ->
     JsonReq = chttpd_external:json_req_obj(Req, Db, DocId),
     JsonDoc = couch_query_servers:json_doc(Doc),
     Cmd = [<<"updates">>, UpdateName],
-    UpdateResp = couch_query_servers:ddoc_prompt(Db, DDoc, Cmd, [JsonDoc, JsonReq]),
-    JsonResp = case UpdateResp of
-        [<<"up">>, {NewJsonDoc}, {JsonResp0}] ->
-            case chttpd:header_value(
-                    Req, "X-Couch-Full-Commit", "false") of
-                "true" ->
-                    Options = [full_commit, {user_ctx, Req#httpd.user_ctx}];
-                _ ->
-                    Options = [{user_ctx, Req#httpd.user_ctx}]
-            end,
-            NewDoc = couch_db:doc_from_json_obj_validate(Db, {NewJsonDoc}),
-            {ok, NewRev} = couch_db:update_doc(Db, NewDoc, Options),
-            NewRevStr = couch_doc:rev_to_str(NewRev),
-            {JsonResp1} = apply_headers(JsonResp0, [
-                {<<"X-Couch-Update-NewRev">>, NewRevStr},
-                {<<"X-Couch-Id">>, couch_util:url_encode(NewDoc#doc.id)}
-            ]),
-            {[{<<"code">>, 201} | JsonResp1]};
-        [<<"up">>, _Other, {JsonResp0}] ->
-            {[{<<"code">>, 200} | JsonResp0]}
-    end,
+    UpdateResp = couch_query_servers:ddoc_prompt(DDoc, Cmd, [JsonDoc, JsonReq]),
+    JsonResp =
+        case UpdateResp of
+            [<<"up">>, {NewJsonDoc}, {JsonResp0}] ->
+                case
+                    chttpd:header_value(
+                        Req, "X-Couch-Full-Commit", "false"
+                    )
+                of
+                    "true" ->
+                        Options = [full_commit, {user_ctx, Req#httpd.user_ctx}];
+                    _ ->
+                        Options = [{user_ctx, Req#httpd.user_ctx}]
+                end,
+                NewDoc = couch_db:doc_from_json_obj_validate(Db, {NewJsonDoc}),
+                {ok, NewRev} = couch_db:update_doc(Db, NewDoc, Options),
+                NewRevStr = couch_doc:rev_to_str(NewRev),
+                {JsonResp1} = apply_headers(JsonResp0, [
+                    {<<"X-Couch-Update-NewRev">>, NewRevStr},
+                    {<<"X-Couch-Id">>, couch_util:url_encode(NewDoc#doc.id)}
+                ]),
+                {[{<<"code">>, 201} | JsonResp1]};
+            [<<"up">>, _Other, {JsonResp0}] ->
+                {[{<<"code">>, 200} | JsonResp0]}
+        end,
     % todo set location field
     chttpd_external:send_external_response(Req, JsonResp).
 
-
-handle_view_list_req(#httpd{method=Method}=Req, Db, DDoc)
-    when Method =:= 'GET' orelse Method =:= 'OPTIONS' ->
+handle_view_list_req(#httpd{method = Method} = Req, Db, DDoc) when
+    Method =:= 'GET' orelse Method =:= 'OPTIONS'
+->
     case Req#httpd.path_parts of
         [_, _, _DName, _, LName, VName] ->
             % Same design doc for view and list
@@ -161,7 +185,7 @@ handle_view_list_req(#httpd{method=Method}=Req, Db, DDoc)
         _ ->
             chttpd:send_error(Req, 404, <<"list_error">>, <<"Bad path.">>)
     end;
-handle_view_list_req(#httpd{method='POST'}=Req, Db, DDoc) ->
+handle_view_list_req(#httpd{method = 'POST'} = Req, Db, DDoc) ->
     chttpd:validate_ctype(Req, "application/json"),
     {Props} = chttpd:json_body_obj(Req),
     Keys = proplists:get_value(<<"keys">>, Props),
@@ -179,7 +203,6 @@ handle_view_list_req(#httpd{method='POST'}=Req, Db, DDoc) ->
 handle_view_list_req(Req, _Db, _DDoc) ->
     chttpd:send_method_not_allowed(Req, "GET,POST,HEAD").
 
-
 handle_view_list(Req, Db, DDoc, LName, VDDoc, VName, Keys) ->
     Args0 = couch_mrview_http:parse_body_and_query(Req, Keys),
     ETagFun = fun(BaseSig, Acc0) ->
@@ -191,67 +214,73 @@ handle_view_list(Req, Db, DDoc, LName, VDDoc, VName, Keys) ->
         ETag = chttpd:make_etag({BaseSig, Parts}),
         case chttpd:etag_match(Req, ETag) of
             true -> throw({etag_match, ETag});
-            false -> {ok, Acc0#lacc{etag=ETag}}
+            false -> {ok, Acc0#lacc{etag = ETag}}
         end
     end,
-    Args = Args0#mrargs{preflight_fun=ETagFun},
+    Args = Args0#mrargs{preflight_fun = ETagFun},
     couch_httpd:etag_maybe(Req, fun() ->
-        couch_query_servers:with_ddoc_proc(Db, DDoc, fun(QServer) ->
-            Acc = #lacc{db=Db, req=Req, qserver=QServer, lname=LName},
+        couch_query_servers:with_ddoc_proc(DDoc, fun(QServer) ->
+            Acc = #lacc{db = Db, req = Req, qserver = QServer, lname = LName},
             case VName of
-              <<"_all_docs">> ->
-                couch_mrview:query_all_docs(Db, Args, fun list_cb/2, Acc);
-              _ ->
-                couch_mrview:query_view(Db, VDDoc, VName, Args, fun list_cb/2, Acc)
+                <<"_all_docs">> ->
+                    couch_mrview:query_all_docs(Db, Args, fun list_cb/2, Acc);
+                _ ->
+                    couch_mrview:query_view(Db, VDDoc, VName, Args, fun list_cb/2, Acc)
             end
         end)
     end).
 
-
-list_cb({meta, Meta}, #lacc{code=undefined} = Acc) ->
-    MetaProps = case couch_util:get_value(total, Meta) of
-        undefined -> [];
-        Total -> [{total_rows, Total}]
-    end ++ case couch_util:get_value(offset, Meta) of
-        undefined -> [];
-        Offset -> [{offset, Offset}]
-    end ++ case couch_util:get_value(update_seq, Meta) of
-        undefined -> [];
-        UpdateSeq -> [{update_seq, UpdateSeq}]
-    end,
+list_cb({meta, Meta}, #lacc{code = undefined} = Acc) ->
+    MetaProps =
+        case couch_util:get_value(total, Meta) of
+            undefined -> [];
+            Total -> [{total_rows, Total}]
+        end ++
+            case couch_util:get_value(offset, Meta) of
+                undefined -> [];
+                Offset -> [{offset, Offset}]
+            end ++
+            case couch_util:get_value(update_seq, Meta) of
+                undefined -> [];
+                UpdateSeq -> [{update_seq, UpdateSeq}]
+            end,
     start_list_resp({MetaProps}, Acc);
-list_cb({row, Row}, #lacc{code=undefined} = Acc) ->
+list_cb({row, Row}, #lacc{code = undefined} = Acc) ->
     {ok, NewAcc} = start_list_resp({[]}, Acc),
     send_list_row(Row, NewAcc);
 list_cb({row, Row}, Acc) ->
     send_list_row(Row, Acc);
 list_cb(complete, Acc) ->
     #lacc{qserver = {Proc, _}, req = Req, resp = Resp0} = Acc,
-    if Resp0 =:= nil ->
-        {ok, #lacc{resp = Resp}} = start_list_resp({[]}, Acc);
-    true ->
-        Resp = Resp0
+    if
+        Resp0 =:= nil ->
+            {ok, #lacc{resp = Resp}} = start_list_resp({[]}, Acc);
+        true ->
+            Resp = Resp0
     end,
     case couch_query_servers:proc_prompt(Proc, [<<"list_end">>]) of
         [<<"end">>, Data, Headers] ->
-            Acc2 = fixup_headers(Headers, Acc#lacc{resp=Resp}),
+            Acc2 = fixup_headers(Headers, Acc#lacc{resp = Resp}),
             #lacc{resp = Resp2} = send_non_empty_chunk(Acc2, Data);
         [<<"end">>, Data] ->
-            #lacc{resp = Resp2} = send_non_empty_chunk(Acc#lacc{resp=Resp}, Data)
+            #lacc{resp = Resp2} = send_non_empty_chunk(Acc#lacc{resp = Resp}, Data)
     end,
     last_chunk(Req, Resp2),
     {ok, Resp2}.
 
 start_list_resp(Head, Acc) ->
-    #lacc{db=Db, req=Req, qserver=QServer, lname=LName} = Acc,
+    #lacc{db = Db, req = Req, qserver = QServer, lname = LName} = Acc,
     JsonReq = json_req_obj(Req, Db),
 
-    [<<"start">>,Chunk,JsonResp] = couch_query_servers:ddoc_proc_prompt(QServer,
-        [<<"lists">>, LName], [Head, JsonReq]),
+    [<<"start">>, Chunk, JsonResp] = couch_query_servers:ddoc_proc_prompt(
+        QServer,
+        [<<"lists">>, LName],
+        [Head, JsonReq]
+    ),
     Acc2 = send_non_empty_chunk(fixup_headers(JsonResp, Acc), Chunk),
     {ok, Acc2}.
 
-fixup_headers(Headers, #lacc{etag=ETag} = Acc) ->
+fixup_headers(Headers, #lacc{etag = ETag} = Acc) ->
     Headers2 = apply_etag(Headers, ETag),
     #extern_resp_args{
         code = Code,
@@ -260,61 +289,66 @@ fixup_headers(Headers, #lacc{etag=ETag} = Acc) ->
     } = chttpd_external:parse_external_response(Headers2),
     Headers3 = chttpd_external:default_or_content_type(CType, ExtHeaders),
     Headers4 = chttpd_util:maybe_add_csp_header("showlist", Headers3, "sandbox"),
-    Acc#lacc{code=Code, headers=Headers4}.
+    Acc#lacc{code = Code, headers = Headers4}.
 
 send_list_row(Row, #lacc{qserver = {Proc, _}, req = Req, resp = Resp} = Acc) ->
-    RowObj = case couch_util:get_value(id, Row) of
-        undefined -> [];
-        Id -> [{id, Id}]
-    end ++ case couch_util:get_value(key, Row) of
-        undefined -> [];
-        Key -> [{key, Key}]
-    end ++ case couch_util:get_value(value, Row) of
-        undefined -> [];
-        Val -> [{value, Val}]
-    end ++ case couch_util:get_value(doc, Row) of
-        undefined -> [];
-        Doc -> [{doc, Doc}]
-    end,
+    RowObj =
+        case couch_util:get_value(id, Row) of
+            undefined -> [];
+            Id -> [{id, Id}]
+        end ++
+            case couch_util:get_value(key, Row) of
+                undefined -> [];
+                Key -> [{key, Key}]
+            end ++
+            case couch_util:get_value(value, Row) of
+                undefined -> [];
+                Val -> [{value, Val}]
+            end ++
+            case couch_util:get_value(doc, Row) of
+                undefined -> [];
+                Doc -> [{doc, Doc}]
+            end,
     try couch_query_servers:proc_prompt(Proc, [<<"list_row">>, {RowObj}]) of
-    [<<"chunks">>, Chunk, Headers] ->
-        Acc2 = send_non_empty_chunk(fixup_headers(Headers, Acc), Chunk),
-        {ok, Acc2};
-    [<<"chunks">>, Chunk] ->
-        Acc2 = send_non_empty_chunk(Acc, Chunk),
-        {ok, Acc2};
-    [<<"end">>, Chunk, Headers] ->
-        #lacc{resp = Resp2} = send_non_empty_chunk(fixup_headers(Headers, Acc), Chunk),
-        {ok, Resp3} = last_chunk(Req, Resp2),
-        {stop, Resp3};
-    [<<"end">>, Chunk] ->
-        #lacc{resp = Resp2} = send_non_empty_chunk(Acc, Chunk),
-        {ok, Resp3} = last_chunk(Req, Resp2),
-        {stop, Resp3}
-    catch Error ->
-        {ok, Resp2} = case Resp of
-            undefined ->
-                {Code, _, _} = chttpd:error_info(Error),
-                #lacc{req=Req, headers=Headers} = Acc,
-                chttpd:start_chunked_response(Req, Code, Headers);
-            _ ->
-                {ok, Resp}
-        end,
-        {ok, Resp3} = chttpd:send_chunked_error(Resp2, Error),
-        {stop, Resp3}
+        [<<"chunks">>, Chunk, Headers] ->
+            Acc2 = send_non_empty_chunk(fixup_headers(Headers, Acc), Chunk),
+            {ok, Acc2};
+        [<<"chunks">>, Chunk] ->
+            Acc2 = send_non_empty_chunk(Acc, Chunk),
+            {ok, Acc2};
+        [<<"end">>, Chunk, Headers] ->
+            #lacc{resp = Resp2} = send_non_empty_chunk(fixup_headers(Headers, Acc), Chunk),
+            {ok, Resp3} = last_chunk(Req, Resp2),
+            {stop, Resp3};
+        [<<"end">>, Chunk] ->
+            #lacc{resp = Resp2} = send_non_empty_chunk(Acc, Chunk),
+            {ok, Resp3} = last_chunk(Req, Resp2),
+            {stop, Resp3}
+    catch
+        Error ->
+            {ok, Resp2} =
+                case Resp of
+                    undefined ->
+                        {Code, _, _} = chttpd:error_info(Error),
+                        #lacc{req = Req, headers = Headers} = Acc,
+                        chttpd:start_chunked_response(Req, Code, Headers);
+                    _ ->
+                        {ok, Resp}
+                end,
+            {ok, Resp3} = chttpd:send_chunked_error(Resp2, Error),
+            {stop, Resp3}
     end.
 
 send_non_empty_chunk(Acc, []) ->
     Acc;
-send_non_empty_chunk(#lacc{resp=undefined} = Acc, Chunk) ->
-    #lacc{req=Req, code=Code, headers=Headers} = Acc,
+send_non_empty_chunk(#lacc{resp = undefined} = Acc, Chunk) ->
+    #lacc{req = Req, code = Code, headers = Headers} = Acc,
     {ok, Resp} = chttpd:start_chunked_response(Req, Code, Headers),
     send_non_empty_chunk(Acc#lacc{resp = Resp}, Chunk);
-send_non_empty_chunk(#lacc{resp=Resp} = Acc, Chunk) ->
+send_non_empty_chunk(#lacc{resp = Resp} = Acc, Chunk) ->
     chttpd:send_chunk(Resp, Chunk),
     Acc.
 
-
 apply_etag(JsonResp, undefined) ->
     JsonResp;
 apply_etag({ExternalResponse}, CurrentEtag) ->
@@ -332,7 +366,7 @@ apply_headers(JsonResp, []) ->
 apply_headers(JsonResp, NewHeaders) ->
     case couch_util:get_value(<<"headers">>, JsonResp) of
         undefined ->
-            {[{<<"headers">>, {NewHeaders}}| JsonResp]};
+            {[{<<"headers">>, {NewHeaders}} | JsonResp]};
         JsonHeaders ->
             Headers = apply_headers1(JsonHeaders, NewHeaders),
             NewKV = {<<"headers">>, Headers},
@@ -344,13 +378,11 @@ apply_headers1(JsonHeaders, [{Key, Value} | Rest]) ->
 apply_headers1(JsonHeaders, []) ->
     JsonHeaders.
 
-
 % Maybe this is in the proplists API
 % todo move to couch_util
 json_apply_field(H, {L}) ->
     json_apply_field(H, L, []).
 
-
 json_apply_field({Key, NewValue}, [{Key, _OldVal} | Headers], Acc) ->
     % drop matching keys
     json_apply_field({Key, NewValue}, Headers, Acc);
@@ -359,8 +391,7 @@ json_apply_field({Key, NewValue}, [{OtherKey, OtherVal} | Headers], Acc) ->
     json_apply_field({Key, NewValue}, Headers, [{OtherKey, OtherVal} | Acc]);
 json_apply_field({Key, NewValue}, [], Acc) ->
     % end of list, add ours
-    {[{Key, NewValue}|Acc]}.
-
+    {[{Key, NewValue} | Acc]}.
 
 % This loads the db info if we have a fully loaded db record, but we might not
 % have the db locally on this node, so then load the info through fabric.
@@ -371,7 +402,9 @@ json_req_obj(Req, Db) ->
             % and json_req_obj calls fabric:get_db_info()
             JRO = fun() -> exit(chttpd_external:json_req_obj(Req, Db)) end,
             {Pid, Ref} = spawn_monitor(JRO),
-            receive {'DOWN', Ref, process, Pid, JsonReq} -> JsonReq end;
+            receive
+                {'DOWN', Ref, process, Pid, JsonReq} -> JsonReq
+            end;
         false ->
             chttpd_external:json_req_obj(Req, Db)
     end.
@@ -381,7 +414,6 @@ last_chunk(Req, undefined) ->
 last_chunk(_Req, Resp) ->
     chttpd:send_chunk(Resp, []).
 
-
 -ifdef(TEST).
 -include_lib("eunit/include/eunit.hrl").
 
@@ -395,7 +427,7 @@ apply_headers_test_() ->
 should_apply_headers() ->
     ?_test(begin
         JsonResp = [{<<"code">>, 201}],
-        Headers  = [{<<"foo">>, <<"bar">>}],
+        Headers = [{<<"foo">>, <<"bar">>}],
         {Props} = apply_headers(JsonResp, Headers),
         JsonHeaders = couch_util:get_value(<<"headers">>, Props),
         ?assertEqual({Headers}, JsonHeaders)
@@ -404,7 +436,7 @@ should_apply_headers() ->
 should_apply_headers_with_merge() ->
     ?_test(begin
         BaseHeaders = [{<<"bar">>, <<"baz">>}],
-        NewHeaders  = [{<<"foo">>, <<"bar">>}],
+        NewHeaders = [{<<"foo">>, <<"bar">>}],
         JsonResp = [
             {<<"code">>, 201},
             {<<"headers">>, {BaseHeaders}}
@@ -418,7 +450,7 @@ should_apply_headers_with_merge() ->
 should_apply_headers_with_merge_overwrite() ->
     ?_test(begin
         BaseHeaders = [{<<"foo">>, <<"bar">>}],
-        NewHeaders  = [{<<"foo">>, <<"baz">>}],
+        NewHeaders = [{<<"foo">>, <<"baz">>}],
         JsonResp = [
             {<<"code">>, 201},
             {<<"headers">>, {BaseHeaders}}
@@ -428,7 +460,6 @@ should_apply_headers_with_merge_overwrite() ->
         ?assertEqual({NewHeaders}, JsonHeaders)
     end).
 
-
 send_list_row_test_() ->
     Cases = couch_tests_combinatorics:product([
         [
@@ -439,26 +470,40 @@ send_list_row_test_() ->
         [
             req,
             undefined
-        ]]),
+        ]
+    ]),
     {"Ensure send_list_row returns a valid response on end or error",
         {setup, fun setup/0, fun(_) -> meck:unload() end, [
             {
                 lists:flatten(io_lib:format("~s -- ~p", [N, R])),
                 should_return_valid_response(F, R)
-            } || [{N, F}, R] <- Cases
-        ]}
-    }.
+            }
+         || [{N, F}, R] <- Cases
+        ]}}.
 
 setup() ->
     ok = application:start(config, permanent),
-    ok = meck:expect(chttpd, send_chunk,
-        fun(Resp, _) -> {ok, Resp} end),
-    ok = meck:expect(chttpd, send_chunked_error,
-        fun(Resp, _) -> {ok, Resp} end),
-    ok = meck:expect(chttpd, start_chunked_response,
-        fun(_, _, _) -> {ok, resp} end),
-    ok = meck:expect(chttpd_external, parse_external_response, 1,
-        #extern_resp_args{headers = []}).
+    ok = meck:expect(
+        chttpd,
+        send_chunk,
+        fun(Resp, _) -> {ok, Resp} end
+    ),
+    ok = meck:expect(
+        chttpd,
+        send_chunked_error,
+        fun(Resp, _) -> {ok, Resp} end
+    ),
+    ok = meck:expect(
+        chttpd,
+        start_chunked_response,
+        fun(_, _, _) -> {ok, resp} end
+    ),
+    ok = meck:expect(
+        chttpd_external,
+        parse_external_response,
+        1,
+        #extern_resp_args{headers = []}
+    ).
 
 should_return_valid_response(Spec, Req) ->
     ?_test(begin
